@@ -2,5 +2,4 @@
 Stores are persistence components for Documents.  Typically, they can act as either a Connector or a Sink
 """
 from .local import LocalDocumentStore, LocalModelStore, TableDataStore
-from .stores import DataStoreHelper, \
-    RemoteDocumentStore, RemoteDictDataStore, RemoteTableDataStore, RemoteModelStore
+from .stores import DataStoreHelper, RemoteDocumentStore, RemoteModelStore, RemoteDataStore
