@@ -9,7 +9,7 @@ from kodexa import Assistant, AssistantResponse, LocalDocumentStore
 from kodexa import ContentEvent, ContentNode, Document, DocumentActor, DocumentTransition, PipelineContext, \
     TableDataStore, TransitionType
 from kodexa.assistant.assistant import AssistantMetadata
-from kodexa.model.model import AssistantEvent, ContentObjectReference, DocumentStore
+from kodexa.model import AssistantEvent, ContentObjectReference, DocumentStore, ActorType
 
 logger = logging.getLogger('kodexa.testing')
 
@@ -233,7 +233,8 @@ class AssistantTestHarness:
             content_provider: optional provider for content
         """
         self.assistant = assistant
-        self.stores = stores
+        from kodexa.model import Store
+        self.stores: List[Store] = stores
         self.kodexa_metadata_path = kodexa_metadata_path
         self.metadata = metadata
         self.content_provider = content_provider
@@ -299,8 +300,10 @@ class AssistantTestHarness:
 
                 if pipeline_context.output_document is not None and assistant_pipeline.write_back_to_store:
                     # We need to build the transition between the old and the new
-                    document_relationship = DocumentTransition(TransitionType.DERIVED, event.content_object.id, None,
-                                                               DocumentActor("testing", "assistant"))
+                    document_relationship = DocumentTransition()
+                    document_relationship.transition_type = TransitionType.derived
+                    document_relationship.source_content_object_id = event.content_object.id
+                    document_relationship.actor = DocumentActor(actorId="testing", actorType=ActorType.assistant)
 
                     store.add_related_document_to_family(event.document_family.id, document_relationship,
                                                          pipeline_context.output_document)
@@ -328,7 +331,7 @@ class AssistantTestHarness:
           The instance of the document store
         """
         for store in self.stores:
-            if event.document_family.store_ref == store.get_ref():
+            if event.document_family.store_ref == store.ref:
                 return store
 
         raise Exception(f"Unable to get store ref {event.document_family.store_ref}")
